| extract_resample_weights | R Documentation |
This function provides a consistent interface to access resample weights
regardless of whether they were added to an rset object or are stored
in tune_results after tuning.
extract_resample_weights(x)
x |
An rset object with resample weights, or a |
A numeric vector of resample weights, or NULL if no weights are present.
## Not run:
library(rsample)
folds <- vfold_cv(mtcars, v = 3)
weighted_folds <- add_resample_weights(folds, c(0.2, 0.3, 0.5))
extract_resample_weights(weighted_folds)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.